Crate cargo_testdox

source ·
A Cargo subcommand for printing your Rust test names as sentences.

Also contains functions to parse the (human-readable) output of cargo test, and to format test names as sentences.

Further reading and context: Test names should be sentences.

Structs

  • The (prettified) name and pass/fail status of a given test.

Enums

  • The status of a given test, as reported by cargo test.

Functions

  • Runs cargo test with any supplied extra arguments, and returns the resulting standard output.
  • Parses a line from the standard output of cargo test.
  • Parses the standard output of cargo test into a vec of TestResult.
  • Formats the name of a test function as a sentence.